Package: IncidencePrevalence
Title: Estimate Incidence and Prevalence using the OMOP Common Data
        Model
Version: 1.2.1
Authors@R: c(
    person("Edward", "Burn", email = "edward.burn@ndorms.ox.ac.uk", 
    role = c("aut", "cre"), 
    comment = c(ORCID = "0000-0002-9286-1128")), 
    person("Berta", "Raventos", email = "braventos@idiapjgol.info", 
    role = c("aut"), 
    comment = c(ORCID = "0000-0002-4668-2970")), 
    person("Martí", "Català", email = "marti.catalasabate@ndorms.ox.ac.uk", 
    role = c("aut"), 
    comment = c(ORCID = "0000-0003-3308-9905")),
    person("Mike", "Du", email = "mike.du@ndorms.ox.ac.uk", role = c("ctb"), 
    comment = c(ORCID = "0000-0002-9517-8834")),
    person("Yuchen", "Guo", email = "yuchen.guo@ndorms.ox.ac.uk", role = c("ctb"), 
           comment = c(ORCID = "0000-0002-0847-4855")),
    person("Adam", "Black", email = "black@ohdsi.org", role = c("ctb"),
    comment = c(ORCID = "0000-0001-5576-8701")),
    person("Ger", "Inberg", email = "g.inberg@erasmusmc.nl", role = c("ctb"),
    comment = c(ORCID = "0000-0001-8993-8748")),
    person("Kim", "Lopez", email = "kim.lopez@spc.ox.ac.uk", role = c("ctb"),
    comment = c(ORCID = "0000-0002-8462-8668"))
    )
Description: Calculate incidence and prevalence using data mapped to the Observational Medical Outcomes Partnership (OMOP) common data model. Incidence and prevalence can be estimated for the total population in a database or for a stratification cohort.
Encoding: UTF-8
RoxygenNote: 7.3.2
Depends: R (>= 4.1)
Imports: CDMConnector (>= 2.0.0), cli (>= 3.0.0), clock, dplyr (>=
        1.1.0), glue (>= 1.5.0), omopgenerics (>= 1.1.0), magrittr (>=
        2.0.0), PatientProfiles (>= 1.3.1), purrr (>= 0.3.5), rlang (>=
        1.0.0), stringr (>= 1.5.0), tidyr (>= 1.2.0)
Suggests: knitr, dbplyr, rmarkdown, RPostgres, duckdb (>= 1.0.0), DBI
        (>= 1.0.0), odbc, here, Hmisc, epitools, tictoc, testthat (>=
        0.3.1), spelling, gt, flextable, ggplot2 (>= 3.4.0), scales (>=
        1.1.0), visOmopResults (>= 1.0.2), patchwork, binom
Config/testthat/edition: 3
Config/testthat/parallel: true
VignetteBuilder: knitr
Language: en-US
License: Apache License (>= 2)
URL: https://darwin-eu.github.io/IncidencePrevalence/
BugReports: https://github.com/darwin-eu/IncidencePrevalence/issues
LazyData: true
NeedsCompilation: no
Packaged: 2025-07-22 19:17:22 UTC; eburn
Author: Edward Burn [aut, cre] (ORCID: <https://orcid.org/0000-0002-9286-1128>),
  Berta Raventos [aut] (ORCID: <https://orcid.org/0000-0002-4668-2970>),
  Martí Català [aut] (ORCID: <https://orcid.org/0000-0003-3308-9905>),
  Mike Du [ctb] (ORCID: <https://orcid.org/0000-0002-9517-8834>),
  Yuchen Guo [ctb] (ORCID: <https://orcid.org/0000-0002-0847-4855>),
  Adam Black [ctb] (ORCID: <https://orcid.org/0000-0001-5576-8701>),
  Ger Inberg [ctb] (ORCID: <https://orcid.org/0000-0001-8993-8748>),
  Kim Lopez [ctb] (ORCID: <https://orcid.org/0000-0002-8462-8668>)
Maintainer: Edward Burn <edward.burn@ndorms.ox.ac.uk>
Repository: CRAN
Date/Publication: 2025-07-22 20:40:23 UTC
Built: R 4.6.0; ; 2026-04-25 13:44:13 UTC; unix
