# Generated by roxygen2: do not edit by hand

export("%>%")
export(asIncidenceResult)
export(asPrevalenceResult)
export(attrition)
export(availableIncidenceGrouping)
export(availablePrevalenceGrouping)
export(benchmarkIncidencePrevalence)
export(bind)
export(cohortCodelist)
export(cohortCount)
export(estimateIncidence)
export(estimatePeriodPrevalence)
export(estimatePointPrevalence)
export(exportSummarisedResult)
export(generateDenominatorCohortSet)
export(generateTargetDenominatorCohortSet)
export(importSummarisedResult)
export(mockIncidencePrevalence)
export(optionsTableIncidence)
export(optionsTablePrevalence)
export(plotIncidence)
export(plotIncidencePopulation)
export(plotPrevalence)
export(plotPrevalencePopulation)
export(settings)
export(suppress)
export(tableIncidence)
export(tableIncidenceAttrition)
export(tablePrevalence)
export(tablePrevalenceAttrition)
importFrom(magrittr,"%>%")
importFrom(omopgenerics,attrition)
importFrom(omopgenerics,bind)
importFrom(omopgenerics,cohortCodelist)
importFrom(omopgenerics,cohortCount)
importFrom(omopgenerics,exportSummarisedResult)
importFrom(omopgenerics,importSummarisedResult)
importFrom(omopgenerics,settings)
importFrom(omopgenerics,suppress)
importFrom(rlang,":=")
importFrom(rlang,.data)
importFrom(rlang,.env)
