---
title: "Calculating incidence"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{a05_Calculating_incidence}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  warning = FALSE, 
  message = FALSE,
  comment = "#>",
  fig.width = 8.5,
  fig.height = 6,
  eval = Sys.getenv("$RUNNER_OS") != "macOS"
)
```


```{r, message= FALSE, warning=FALSE, echo=FALSE}
library(here)
```

# Introduction
Incidence rates describe the rate at which new events occur in a population, with the denominator the person-time at risk of the event during this period. In the previous vignettes we have seen how we can identify a set of denominator and outcome cohorts. Incidence rates can then be calculated using time contributed from these denominator cohorts up to their entry into an outcome cohort.

There are a number of options to consider when calculating incidence rates. This package accommodates various parameters when estimating incidence. In particular, the **outcome washout** (the number of days used for a 'washout' period between the end of one outcome ending and an individual starting to contribute time at risk again) and allowing **repeated events** (whether individuals are able to contribute multiple events during the study period or if they will only contribute time up to their first event during the study period) are particularly important analytic settings to consider. In addition, censoring events can also be specified to limit time at risk.

### No washout, no repetitive events
In this example there is no outcome washout specified and repetitive events are not allowed, so individuals contribute time up to their first event during the study period.
```{r,echo=FALSE, out.width="80%"}
knitr::include_graphics(here("vignettes/inc_no_rep_no_washout.png"))
```

### Washout all history, no repetitive events
In this example the outcome washout is all history and repetitive events are not allowed. As before individuals contribute time up to their first event during the study period, but having an outcome prior to the study period (such as person "3") means that no time at risk is contributed.

```{r,echo=FALSE, out.width="80%"}
knitr::include_graphics(here("vignettes/inc_no_rep_washout_all.png"))
```

### Some washout, no repetitive events
In this example there is some amount of outcome washout and repetitive events are not allowed. As before individuals contribute time up to their first event during the study period, but having an outcome prior to the study period (such as person "3") means that time at risk is only contributed once sufficient time has passed for the outcome washout criteria to have been satisfied.

```{r,echo=FALSE, out.width="80%"}
knitr::include_graphics(here("vignettes/inc_no_rep_some_washout.png"))
```

### Some washout, repetitive events
Now repetitive events are allowed with some amount of outcome washout specified. So individuals contribute time up to their first event during the study period, and then after passing the outcome washout requirement they begin to contribute time at risk again.

```{r,echo=FALSE, out.width="80%"}
knitr::include_graphics(here("vignettes/inc_rep_some_washout.png"))
```

### Some washout, repetitive events, censoring event
We can also incorporate a censoring event. Here any time at risk after this censoring event will be excluded.

```{r,echo=FALSE, out.width="80%"}
knitr::include_graphics(here("vignettes/inc_rep_some_washout_censor.png"))
```

# Outcome definition
Outcome cohorts are defined externally. When creating outcome cohorts for estimating incidence, the most important recommendations for defining an outcome cohort for calculating incidence are:

1. Do not restrict outcome cohorts to first events only. This will impact the ability to exclude participants (as they can be excluded based on the prior latest event) and to capture more than one event per person (which is an option allowed in the package).
2. Set an appropriate cohort exit strategy. If we want to consider multiple events per person, the duration of these events will be of importance, as we are not going to capture subsequent events if prior events have not yet been concluded. In addition, outcome washouts will be implemented relative to cohort exit from any previous event. 
3. Do not add further restrictions on sex, age and prior history requirements. These can be specified when identifying the denominator population with the `generateDenominatorCohortSet()` function.

# Using estimateIncidence()
`estimateIncidence()` is the function we use to estimate incidence rates. To demonstrate its use, let´s load the IncidencePrevalence package (along with a couple of packages to help for subsequent plots) and generate 20,000 example patients using the `mockIncidencePrevalence()` function, from whom we´ll create a denominator population without adding any restrictions other than a study period. In this example we'll use permanent tables (rather than temporary tables which would be used by default).   

```{r setup}
library(IncidencePrevalence)
library(dplyr)
library(tidyr)
library(ggplot2)
library(patchwork)

cdm <- mockIncidencePrevalence(
  sampleSize = 20000,
  earliestObservationStartDate = as.Date("1960-01-01"),
  minOutcomeDays = 365,
  outPre = 0.3
)

cdm <- generateDenominatorCohortSet(
  cdm = cdm, name = "denominator",
  cohortDateRange = c(as.Date("1990-01-01"), as.Date("2009-12-31")),
  ageGroup = list(c(0, 150)),
  sex = "Both",
  daysPriorObservation = 0
)

cdm$denominator %>%
  glimpse()
```


Let´s first calculate incidence rates on a yearly basis, without allowing repetitive events
```{r, message= FALSE, warning=FALSE}
inc <- estimateIncidence(
  cdm = cdm,
  denominatorTable = "denominator",
  outcomeTable = "outcome",
  interval = "years",
  outcomeWashout = 0,
  repeatedEvents = FALSE
)

inc %>%
  glimpse()

plotIncidence(inc)
```

As well as plotting our prevalence estimates, we can also plot the population for whom these were calculated. Here we´ll plot outcome and population counts together.
```{r, message= FALSE, warning=FALSE}
outcome_plot <- plotIncidencePopulation(result = inc, y = "outcome_count") +
  xlab("") +
  theme(axis.text.x = element_blank()) +
  ggtitle("a) Number of outcomes by year")
denominator_plot <- plotIncidencePopulation(result = inc) +
  ggtitle("b) Number of people in denominator population by year")
pys_plot <- plotIncidencePopulation(result = inc, y = "person_years") +
  ggtitle("c) Person-years contributed by year")

outcome_plot / denominator_plot / pys_plot
```

Now with a washout of all prior history while still not allowing repetitive events. Here we use `Inf` to specify that we will use a washout of all prior history for an individual.
```{r, message= FALSE, warning=FALSE}
inc <- estimateIncidence(
  cdm = cdm,
  denominatorTable = "denominator",
  outcomeTable = "outcome",
  interval = "years",
  outcomeWashout = Inf,
  repeatedEvents = FALSE
)

inc %>%
  glimpse()

plotIncidence(inc)
```

Now we´ll set the washout to 180 days while still not allowing repetitive events
```{r, message= FALSE, warning=FALSE}
inc <- estimateIncidence(
  cdm = cdm,
  denominatorTable = "denominator",
  outcomeTable = "outcome",
  interval = "years",
  outcomeWashout = 180,
  repeatedEvents = FALSE
)

inc %>%
  glimpse()

plotIncidence(inc)
```

And now we´ll set the washout to 180 days and allow repetitive events
```{r, message= FALSE, warning=FALSE}
inc <- estimateIncidence(
  cdm = cdm,
  denominatorTable = "denominator",
  outcomeTable = "outcome",
  interval = "years",
  outcomeWashout = 180,
  repeatedEvents = TRUE
)

inc %>%
  glimpse()

plotIncidence(inc)
```

Finally, we can apply a censoring event. For this we will need to point to a cohort which we want to be used for censoring. As with the outcome cohort, censoring cohorts need to be defined externally. But once created we can use these to limit follow-up. Note, only one censoring cohort can be used and this cohort must only include one record per person
```{r, message= FALSE, warning=FALSE}
inc <- estimateIncidence(
  cdm = cdm,
  denominatorTable = "denominator",
  outcomeTable = "outcome",
  censorTable = "censor",
  interval = "years",
  outcomeWashout = 180,
  repeatedEvents = TRUE
)

inc %>%
  glimpse()

plotIncidence(inc)
```

## Stratified analyses
As with prevalence, if we specified multiple denominator populations results will be returned for each. Here for example we define three age groups for denominator populations and get three sets of estimates back when estimating incidence

```{r}
cdm <- generateDenominatorCohortSet(
  cdm = cdm, name = "denominator_age_sex",
  cohortDateRange = c(as.Date("1990-01-01"), as.Date("2009-12-31")),
  ageGroup = list(
    c(0, 39),
    c(41, 65),
    c(66, 150)
  ),
  sex = "Both",
  daysPriorObservation = 0
)
inc <- estimateIncidence(
  cdm = cdm,
  denominatorTable = "denominator_age_sex",
  outcomeTable = "outcome",
  interval = "years",
  outcomeWashout = 180,
  repeatedEvents = TRUE
)

plotIncidence(inc) + 
  facet_wrap(vars(denominator_age_group), ncol = 1)
```

We can also plot person years by year for each strata.
```{r, message= FALSE, warning=FALSE}
pys_plot <- plotIncidencePopulation(result = inc, y = "person_years")

pys_plot +
  facet_wrap(vars(denominator_age_group), ncol = 1)
```

And again, as with prevalence while we specify time-varying stratifications when defining our denominator populations, if we have time-invariant stratifications we can include these at the the estimation stage. 

```{r, fig.width=13}
cdm$denominator <- cdm$denominator %>%
  mutate(group = if_else(as.numeric(subject_id) < 3000, "first", "second"))

inc <- estimateIncidence(
  cdm = cdm,
  denominatorTable = "denominator",
  outcomeTable = "outcome",
  strata = list("group"),
  outcomeWashout = 180,
  repeatedEvents = TRUE
)

plotIncidence(inc,
  colour = "group"
) + 
  facet_wrap(vars(group), ncol = 1)

cdm$denominator <- cdm$denominator %>%
  mutate(
    group_1 = if_else(as.numeric(subject_id) < 3000, "first", "second"),
    group_2 = if_else(as.numeric(subject_id) < 2000, "one", "two")
  )

inc <- estimateIncidence(
  cdm = cdm,
  denominatorTable = "denominator",
  outcomeTable = "outcome",
  strata = list(
    c("group_1"), # for just group_1
    c("group_2"), # for just group_2
    c("group_1", "group_2")
  ), # for group_1 and group_2
  outcomeWashout = 180,
  repeatedEvents = TRUE
)

plotIncidence(inc,
  colour = c("group_1", "group_2")
) +
  facet_wrap(vars(group_1, group_2), ncol = 2) +
  theme(legend.position = "top")
```


### Other parameters
In the examples above, we have used calculated incidence rates by months and years, but it can be also calculated by weeks, months, quarters, or for the entire study time period. In addition, we can decide whether to include time intervals that are not fully captured in the database (e.g., having data up to June for the last study year when computing yearly incidence rates). By default, incidence will only be estimated for those intervals where the denominator cohort captures all the interval (completeDatabaseIntervals=TRUE).

Given that we can set `estimateIncidence()` to exclude individuals based on other parameters (e.g., outcomeWashout), it is important to note that the denominator population used to compute incidence rates might differ from the one calculated with `generateDenominatorCohortSet()`. 95 % confidence intervals are calculated using the exact method. 

```{r, message=TRUE, warning=FALSE}
inc <- estimateIncidence(
  cdm = cdm,
  denominatorTable = "denominator",
  outcomeTable = "outcome",
  interval = c("weeks"),
  completeDatabaseIntervals = FALSE,
  outcomeWashout = 180,
  repeatedEvents = TRUE
)
```

### Analysis attrition
As with our prevalence results, we can also view the attrition associate with estimating incidence.

```{r, message= FALSE, warning=FALSE}
inc <- estimateIncidence(
  cdm = cdm,
  denominatorTable = "denominator",
  outcomeTable = "outcome",
  interval = c("Years"),
  outcomeWashout = 180,
  repeatedEvents = TRUE
)
tableIncidenceAttrition(inc, style = "darwin")
```
